==> ava-fixture-0.8.0.tgz: package/README.md <==
# ava-fixture

[![stable][stable-image]][stable-url]
[![NPM version][npm-image]][npm-url]
[![NPM downloads][downloads-image]][downloads-url]
[![Build status][travis-image]][travis-url]
[![Coverage Status][coveralls-image]][coveralls-url]
![badge-size-es5-url]
![badge-size-es2015-url]

Helps you to easily write fixture tests with [`ava`](https://github.com/avajs/ava).

## What is Fixture Test

Fixture tests are tests that require access to some files.
The tests may write files and in that case the files can be compared with a baseline (i.e. Baseline Tests)

## Usage

Assume you have the following folders:

```sh
+ fixtures
  + cases
    + case-1
      - something.txt
    + other-cases
  + baselines
    + case-1
      - something.txt
  + results # empty, not check into repository
```

When you only need to access files in each test case (i.e. don't need to perform baseline test):

```ts
import ava from 'ava';
import fixture from 'ava-fixture';

// Point to the base folder which contain the fixtures.
// Relative path starts from project root.
const ftest = fixture(ava, 'fixture/cases');

// You can also use absolute path.
// const ftest = fixture(ava, join(process.cwd(), 'fixture/cases'));

ftest('test title', 'case-1', (t, d) => {
  // t is ava test assertion.
  t.is(d.casePath, 'path to the case')

  // If you need `cwd` at the case path.
  process.chdir(d.casePath)

  // ...test away
});

// test title can be omitted
ftest('case-1', (t, d) => {
  // ...
})

// go through each test
ftest.each((t, d) => {
  t.is(d.caseName, 'name of the case')
  t.is(d.casePath, 'path to the case')
})
```

When you want to perform baseline tests:

```ts
import test from 'ava';
import fixture from 'ava-fixture';

// Point to the base folder which contain the fixtures.
// Relative path starts from project root.
const btest = fixture(test, 'fixture/cases', 'fixture/baselines', 'fixture/results');

btest('test title', 'case-1', (t, d) => {
  // t is ava test assertion.
  t.is(d.casePath, 'path to the case')
  t.is(d.baselinePath, 'path to the baseline of the case')
  t.is(d.resultPath, 'where you should put your result')

  // If you need `cwd` at the case path.
  process.chdir(d.casePath)

  // ...do tests

  // `d.match()` will check if the result folder has the same content as the baseline folder.
  return d.match()
});

// test title can be omitted
btest('case-1', (t, d) => {
  t.is(d.casePath, 'path to the case')
  t.is(d.baselinePath, 'path to the baseline of the case')
  t.is(d.resultPath, 'where you should put your result')

  return d.match()
})

// go through each test
ftest.each((t, d) => {
  t.is(d.caseName, 'name of the case')
  t.is(d.casePath, 'path to the case')
  t.is(d.baselinePath, 'path to the baseline of the case')
  t.is(d.resultPath, 'where you should put your result')

  return d.match()
})
```

## Other API

```ts
import test from 'ava';
import fixture from 'ava-fixture';

const ftest = fixture(test, 'fixture/cases');

// Chainable: e.g. `ftest.only.skip.failing()`
ftest.only(...)
ftest.skip(...)
ftest.failing(...)
ftest.only.each.failing(...)
```

For `before()`, `beforeEach()`, `after()`, `afterEach()`, `todo()`, use `ava` directly.

## Contribute

```sh
# right after clone
npm install

# begin making changes
git checkout -b <branch>
npm run watch

# edit `webpack.config.es5.js` and `rollup.config.es2015.js` to exclude dependencies for the bundle if needed

# after making change(s)
git commit -m "<commit message>"
git push

# create PR
```

## Npm Commands

There are a few useful commands you can use during development.

```sh
# Run tests (and lint) automatically whenever you save a file.
npm run watch

# Run tests with coverage stats (but won't fail you if coverage does not meet criteria)
npm run test

# Manually verify the project.
# This will be ran during 'npm preversion' so you normally don't need to run this yourself.
npm run verify

# Build the project.
# You normally don't need to do this.
npm run build

# Run tslint
# You normally don't need to do this as `npm run watch` and `npm version` will automatically run lint for you.
npm run lint
```

Generated by [`generator-unional@0.9.0`](https://github.com/unional/unional-cli)

[stable-image]: http://badges.github.io/stability-badges/dist/stable.svg
[stable-url]: http://github.com/badges/stability-badges
[npm-image]: https://img.shields.io/npm/v/ava-fixture.svg?style=flat
[npm-url]: https://npmjs.org/package/ava-fixture
[downloads-image]: https://img.shields.io/npm/dm/ava-fixture.svg?style=flat
[downloads-url]: https://npmjs.org/package/ava-fixture
[travis-image]: https://img.shields.io/travis/unional/ava-fixture.svg?style=flat
[travis-url]: https://travis-ci.org/unional/ava-fixture
[coveralls-image]: https://coveralls.io/repos/github/unional/ava-fixture/badge.svg
[coveralls-url]: https://coveralls.io/github/unional/ava-fixture
[badge-size-es5-url]: http://img.badgesize.io/unional/ava-fixture/master/dist/ava-fixture.es5.js.svg?label=es5_size
[badge-size-es2015-url]: http://img.badgesize.io/unional/ava-fixture/master/dist/ava-fixture.es2015.js.svg?label=es2015_size

==> ava-fixture-0.8.1.tgz: package/README.md <==
# ava-fixture

[![stable][stable-image]][stable-url]
[![NPM version][npm-image]][npm-url]
[![NPM downloads][downloads-image]][downloads-url]
[![Build status][travis-image]][travis-url]
[![Coverage Status][coveralls-image]][coveralls-url]
![badge-size-es5-url]
![badge-size-es2015-url]

This library helps you to write fixture tests: test-per-folder or test-per-file.

## Usage

For example, you are testing code that process files (e.g. a compiler, config-reader, etc).

You put each test case inside its own folder:

```sh
+ fixtures
  + cases
    + empty
      - somefiles
    + basic-case
      - someOtherFiles
    + single-line
      - ...
    + ...
```

You can run each test case like this:

```ts
import ava from 'ava';
import fixture from 'ava-fixture';

// Point to the base folder which contain the fixtures.
// Use relative path starts from project root or absolute path
const ftest = fixture(ava, 'fixtures/cases', 'fixtures/baselines', 'fixtures/results');

ftest.each((t, d) => {
  // d.caseName: 'empty', 'basic-case', 'single-line', etc
  // d.casePath: absolute path points to each test case folder
  // d.resultPath: absolute path points to each test result folder

  // Your test target reads from `d.casePath` and writes to `d.resultPath`
  target.process(d.casePath, d.resultPath)

  // d.match() will compare the result folder against the baseline folder
  return d.match()
})
```

Assume you have the following folders:

```sh
+ fixtures
  + cases
    + case-1
      - something.txt
    + other-cases
  + baselines
    + case-1
      - something.txt
  + results # empty, not check into repository
```

You can also use this library to run tests that only read files:

```ts
import ava from 'ava';
import fixture from 'ava-fixture';

// Point to the base folder which contain the fixtures.
// Relative path starts from project root.
const ftest = fixture(ava, 'fixture/cases');

ftest('test title', 'case-1', (t, d) => {
  // t is ava test assertion.
  t.is(d.casePath, 'absolut path the the case folder')

  const result = target.read(d.casePath)

  t.deepEqual(result, 'expected result')
});

// test title can be omitted
ftest('case-1', (t, d) => {
  // ...
})

// go through each test
ftest.each((t, d) => {
  // ...
})

// or run certain test based on filter
ftest.each(/some filter/, (t, d) => {
  // ...
})
```

## Other API

```ts
import test from 'ava';
import fixture from 'ava-fixture';

const ftest = fixture(test, 'fixture/cases');

ftest.only(...)
ftest.skip(...)
ftest.failing(...)
ftest.only.each.failing(...)
```

For `before()`, `beforeEach()`, `after()`, `afterEach()`, `todo()`, use `ava` directly.

## Contribute

```sh
# right after clone
npm install

# begin making changes
git checkout -b <branch>
npm run watch

# edit `webpack.config.es5.js` and `rollup.config.es2015.js` to exclude dependencies for the bundle if needed

# after making change(s)
git commit -m "<commit message>"
git push

# create PR
```

## Npm Commands

There are a few useful commands you can use during development.

```sh
# Run tests (and lint) automatically whenever you save a file.
npm run watch

# Run tests with coverage stats (but won't fail you if coverage does not meet criteria)
npm run test

# Manually verify the project.
# This will be ran during 'npm preversion' so you normally don't need to run this yourself.
npm run verify

# Build the project.
# You normally don't need to do this.
npm run build

# Run tslint
# You normally don't need to do this as `npm run watch` and `npm version` will automatically run lint for you.
npm run lint
```

Generated by [`generator-unional@0.9.0`](https://github.com/unional/unional-cli)

[stable-image]: http://badges.github.io/stability-badges/dist/stable.svg
[stable-url]: http://github.com/badges/stability-badges
[npm-image]: https://img.shields.io/npm/v/ava-fixture.svg?style=flat
[npm-url]: https://npmjs.org/package/ava-fixture
[downloads-image]: https://img.shields.io/npm/dm/ava-fixture.svg?style=flat
[downloads-url]: https://npmjs.org/package/ava-fixture
[travis-image]: https://img.shields.io/travis/unional/ava-fixture.svg?style=flat
[travis-url]: https://travis-ci.org/unional/ava-fixture
[coveralls-image]: https://coveralls.io/repos/github/unional/ava-fixture/badge.svg
[coveralls-url]: https://coveralls.io/github/unional/ava-fixture
[badge-size-es5-url]: http://img.badgesize.io/unional/ava-fixture/master/dist/ava-fixture.es5.js.svg?label=es5_size
[badge-size-es2015-url]: http://img.badgesize.io/unional/ava-fixture/master/dist/ava-fixture.es2015.js.svg?label=es2015_size
